@@ -20,6 +20,8 @@ from typing import (
 
 from sanic.exceptions import SanicException
 
+from sanic_ext.utils.typing import contains_annotations, is_pydantic
+
 from .types import Definition, Schema
 
 
@@ -79,7 +81,9 @@ class MediaType(Definition):
     schema: Schema
     example: Any
 
-    def __init__(self, schema: Schema, **kwargs):
+    def __init__(self, schema: Union[Schema, Dict[str, Any]], **kwargs):
+        if isinstance(schema, dict) and contains_annotations(schema):
+            schema = Schema.make(schema)
         super().__init__(schema=schema, **kwargs)
 
     @staticmethod
@@ -90,6 +94,12 @@ class MediaType(Definition):
                 kwargs = {**value}
                 value = kwargs.pop("schema")
             return MediaType(value, **kwargs)
+        # See https://github.com/sanic-org/sanic-ext/issues/152
+        # The following lines will automatically inject pydantic models as
+        # components if that feature is desired. Until that decision is made
+        # this commented out code will remain.
+        # elif isclass(value) and is_pydantic(value):
+        #     return MediaType(Component(value))
         return MediaType(Schema.make(value))
 
     @staticmethod
@@ -124,7 +134,7 @@ class Response(Definition):
         )
 
     @staticmethod
-    def make(content, description: str = None, **kwargs):
+    def make(content, description: Optional[str] = None, **kwargs):
         if not description:
             description = "Default Response"
 
@@ -175,7 +185,7 @@ class ExternalDocumentation(Definition):
         super().__init__(url=url, description=description)
 
     @staticmethod
-    def make(url: str, description: str = None):
+    def make(url: str, description: Optional[str] = None):
         return ExternalDocumentation(url, description)
 
 
@@ -188,7 +198,7 @@ class Header(Definition):
         super().__init__(url=url, description=description)
 
     @staticmethod
-    def make(url: str, description: str = None):
+    def make(url: str, description: Optional[str] = None):
         return Header(url, description)
 
 
@@ -315,8 +325,7 @@ class SecurityScheme(Definition):
 
     @staticmethod
     def make(_type: str, cls: Type, **kwargs):
-        params = cls.__dict__ if hasattr(cls, "__dict__") else {}
-
+        params: Dict[str, Any] = getattr(cls, "__dict__", {})
         return SecurityScheme(_type, **params, **kwargs)
 
 
@@ -337,7 +346,10 @@ class Server(Definition):
     __nullable__ = None
 
     def __init__(
-        self, url: str, description: str = None, variables: dict = None
+        self,
+        url: str,
+        description: Optional[str] = None,
+        variables: Optional[Dict[str, Any]] = None,
     ):
         super().__init__(
             url=url, description=description, variables=variables or []
@@ -397,7 +409,20 @@ def Component(
     if not spec.has_component(field, name):
         prop_info = hints[field]
         type_ = prop_info.__args__[1]
-        component = type_.make(obj) if hasattr(type_, "make") else type_(obj)
+        if is_pydantic(obj):
+            try:
+                schema = obj.schema
+            except AttributeError:
+                schema = obj.__pydantic_model__.schema
+            component = schema(ref_template="#/components/schemas/{model}")
+            definitions = component.pop("definitions", None)
+            if definitions:
+                for key, value in definitions.items():
+                    spec.add_component(field, key, value)
+        else:
+            component = (
+                type_.make(obj) if hasattr(type_, "make") else type_(obj)
+            )
 
         spec.add_component(field, name, component)
 
