@@ -15,14 +15,14 @@ from typing import (
     get_type_hints,
 )
 
-from sanic_routing.patterns import nonemptystr
+from sanic_routing.patterns import alpha, ext, nonemptystr, parse_date, slug
 
 from sanic_ext.utils.typing import is_attrs, is_generic, is_pydantic
 
 try:
     import attrs
 
-    NOTHING = attrs.NOTHING
+    NOTHING: Any = attrs.NOTHING
 except ImportError:
     NOTHING = object()
 
@@ -123,7 +123,7 @@ class Schema(Definition):
             return Integer(**kwargs)
         elif value == float:
             return Float(**kwargs)
-        elif value == str or value is nonemptystr:
+        elif value == str or value in (nonemptystr, ext, slug, alpha):
             return String(**kwargs)
         elif value == bytes:
             return Byte(**kwargs)
@@ -133,7 +133,7 @@ class Schema(Definition):
             return Date(**kwargs)
         elif value == time:
             return Time(**kwargs)
-        elif value == datetime:
+        elif value == datetime or value is parse_date:
             return DateTime(**kwargs)
         elif value == uuid.UUID:
             return UUID(**kwargs)
@@ -179,6 +179,7 @@ class Schema(Definition):
             kwargs["additionalProperties"] = Schema.make(args[1])
             return Object(**kwargs)
         elif (is_generic(value) or is_generic(_type)) and origin == list:
+            kwargs.pop("items", None)
             return Array(Schema.make(args[0]), **kwargs)
         elif _type is type(Enum):
             available = [item.value for item in value.__members__.values()]
@@ -363,11 +364,32 @@ def _properties(value: object) -> Dict:
 
     cls = value if callable(value) else value.__class__
     extra = value if isinstance(value, dict) else {}
-    return {
-        k: v
-        for k, v in {**fields, **get_type_hints(cls), **extra}.items()
-        if not k.startswith("_")
-    }
+    try:
+        annotations = get_type_hints(cls)
+    except NameError:
+        if hasattr(value, "__annotations__"):
+            annotations = value.__annotations__
+        else:
+            annotations = {}
+    annotations.pop("return", None)
+    try:
+        output = {
+            k: v
+            for k, v in {**fields, **annotations, **extra}.items()
+            if not k.startswith("_")
+            and not (
+                isclass(v)
+                and isclass(cls)
+                and v.__qualname__.endswith(
+                    f"{getattr(cls, '__name__', '<unknown>')}."
+                    f"{getattr(v, '__name__', '<unknown>')}"
+                )
+            )
+        }
+    except TypeError:
+        return {}
+
+    return output
 
 
 def _extract(item):
@@ -378,4 +400,4 @@ def _extract(item):
 
 
 def _is_property(item):
-    return not isfunction(item) and not ismethod(item) and not isclass(item)
+    return not isfunction(item) and not ismethod(item)
